'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = _interopDefault(require('react'));
var PropTypes = _interopDefault(require('prop-types'));
var FlexGrid = _interopDefault(require('@tds/core-flex-grid'));
var DecorativeIcon = _interopDefault(require('@tds/core-decorative-icon'));
var Paragraph = _interopDefault(require('@tds/core-paragraph'));
var Box = _interopDefault(require('@tds/core-box'));

var asyncGenerator = function () {
  function AwaitValue(value) {
    this.value = value;
  }

  function AsyncGenerator(gen) {
    var front, back;

    function send(key, arg) {
      return new Promise(function (resolve, reject) {
        var request = {
          key: key,
          arg: arg,
          resolve: resolve,
          reject: reject,
          next: null
        };

        if (back) {
          back = back.next = request;
        } else {
          front = back = request;
          resume(key, arg);
        }
      });
    }

    function resume(key, arg) {
      try {
        var result = gen[key](arg);
        var value = result.value;

        if (value instanceof AwaitValue) {
          Promise.resolve(value.value).then(function (arg) {
            resume("next", arg);
          }, function (arg) {
            resume("throw", arg);
          });
        } else {
          settle(result.done ? "return" : "normal", result.value);
        }
      } catch (err) {
        settle("throw", err);
      }
    }

    function settle(type, value) {
      switch (type) {
        case "return":
          front.resolve({
            value: value,
            done: true
          });
          break;

        case "throw":
          front.reject(value);
          break;

        default:
          front.resolve({
            value: value,
            done: false
          });
          break;
      }

      front = front.next;

      if (front) {
        resume(front.key, front.arg);
      } else {
        back = null;
      }
    }

    this._invoke = send;

    if (typeof gen.return !== "function") {
      this.return = undefined;
    }
  }

  if (typeof Symbol === "function" && Symbol.asyncIterator) {
    AsyncGenerator.prototype[Symbol.asyncIterator] = function () {
      return this;
    };
  }

  AsyncGenerator.prototype.next = function (arg) {
    return this._invoke("next", arg);
  };

  AsyncGenerator.prototype.throw = function (arg) {
    return this._invoke("throw", arg);
  };

  AsyncGenerator.prototype.return = function (arg) {
    return this._invoke("return", arg);
  };

  return {
    wrap: function (fn) {
      return function () {
        return new AsyncGenerator(fn.apply(this, arguments));
      };
    },
    await: function (value) {
      return new AwaitValue(value);
    }
  };
}();





var classCallCheck = function (instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
};

var createClass = function () {
  function defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  return function (Constructor, protoProps, staticProps) {
    if (protoProps) defineProperties(Constructor.prototype, protoProps);
    if (staticProps) defineProperties(Constructor, staticProps);
    return Constructor;
  };
}();







var _extends = Object.assign || function (target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i];

    for (var key in source) {
      if (Object.prototype.hasOwnProperty.call(source, key)) {
        target[key] = source[key];
      }
    }
  }

  return target;
};



var inherits = function (subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      enumerable: false,
      writable: true,
      configurable: true
    }
  });
  if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
};









var objectWithoutProperties = function (obj, keys) {
  var target = {};

  for (var i in obj) {
    if (keys.indexOf(i) >= 0) continue;
    if (!Object.prototype.hasOwnProperty.call(obj, i)) continue;
    target[i] = obj[i];
  }

  return target;
};

var possibleConstructorReturn = function (self, call) {
  if (!self) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return call && (typeof call === "object" || typeof call === "function") ? call : self;
};

var safeRest = (function (_ref) {
  var style = _ref.style,
      className = _ref.className,
      props = objectWithoutProperties(_ref, ["style", "className"]);
  return props;
});

var ColoredTextProvider = function (_React$Component) {
  inherits(ColoredTextProvider, _React$Component);

  function ColoredTextProvider() {
    classCallCheck(this, ColoredTextProvider);
    return possibleConstructorReturn(this, (ColoredTextProvider.__proto__ || Object.getPrototypeOf(ColoredTextProvider)).apply(this, arguments));
  }

  createClass(ColoredTextProvider, [{
    key: 'getChildContext',
    value: function getChildContext() {
      return {
        inheritColor: true
      };
    }
  }, {
    key: 'render',
    value: function render() {
      var _props = this.props,
          colorClassName = _props.colorClassName,
          children = _props.children;


      return React.createElement(
        'div',
        { className: colorClassName },
        children
      );
    }
  }]);
  return ColoredTextProvider;
}(React.Component);

ColoredTextProvider.propTypes = {
  colorClassName: PropTypes.string.isRequired,
  children: PropTypes.node.isRequired
};

ColoredTextProvider.childContextTypes = {
  inheritColor: PropTypes.bool
};

var messagingStyles = { "default": "TDS_Messaging-modules__default___2B8Di", "success": "TDS_Messaging-modules__success___3kyw2", "error": "TDS_Messaging-modules__error___3NArF", "errorText": "TDS_Messaging-modules__errorText___IDcbb", "disabledText": "TDS_Messaging-modules__disabledText___1bjON" };

var styles = { "instructional": "TDS_Notification-modules__instructional___1XRsw TDS_Messaging-modules__default___2B8Di", "branded": "TDS_Notification-modules__branded___3bfSl", "success": "TDS_Notification-modules__success___2_46M TDS_Messaging-modules__success___3kyw2", "error": "TDS_Notification-modules__error___JV-5X TDS_Messaging-modules__error___3NArF" };

var iconByVariant = {
  success: {
    symbol: 'checkmark',
    color: 'primary'
  },
  error: {
    symbol: 'exclamationPointCircle',
    color: 'error'
  }
};

var isImportant = function isImportant(variant) {
  return variant === 'success' || variant === 'error';
};

var renderIcon = function renderIcon(icon) {
  return React.createElement(DecorativeIcon, { symbol: icon.symbol, variant: icon.color });
};

var renderContent = function renderContent(variant, children) {
  var content = React.createElement(
    Paragraph,
    { bold: isImportant(variant) },
    children
  );

  if (variant === 'error') {
    return React.createElement(
      ColoredTextProvider,
      { colorClassName: messagingStyles.errorText },
      content
    );
  }

  return content;
};

/**
 * @version 1.0.2
 *
 * A banner that highlights important messages.
 */
var Notification = function Notification(_ref) {
  var variant = _ref.variant,
      children = _ref.children,
      rest = objectWithoutProperties(_ref, ['variant', 'children']);
  return React.createElement(
    Box,
    _extends({}, safeRest(rest), { vertical: 3, dangerouslyAddClassName: styles[variant] }),
    React.createElement(
      FlexGrid,
      { limitWidth: true },
      React.createElement(
        FlexGrid.Col,
        null,
        React.createElement(
          Box,
          { inline: true, between: 3 },
          isImportant(variant) ? renderIcon(iconByVariant[variant]) : undefined,
          renderContent(variant, children)
        )
      )
    )
  );
};

Notification.propTypes = {
  /**
   * The appearance.
   */
  variant: PropTypes.oneOf(['instructional', 'branded', 'success', 'error']),
  /**
   * The message. Can be raw text or text components.
   */
  children: PropTypes.node.isRequired
};

Notification.defaultProps = {
  variant: 'instructional'
};

module.exports = Notification;
//# sourceMappingURL=index.cjs.js.map
